@@ -2,7 +2,6 @@
 # coding=utf-8
 from __future__ import print_function
 from .rpc_client import rpc_client
-from . import __version__
 import feedparser
 import argparse
 import hashlib
@@ -14,6 +13,8 @@ import time
 import sys
 import os
 
+__version__ = '0.3.3'
+
 if sys.version_info[0] < 3:
     from urlparse import urlparse
     from urllib import unquote
@@ -61,6 +62,7 @@ def utfme(elem):
 class TRMaid(object):
 
     def __init__(self, config_file=CONF_FILE_FULL, verbose=False):
+        config_file = os.path.expanduser(config_file)
         if not os.path.exists(config_file):
             msg_and_exit(
                 'Please create config file called %s.' % config_file,
